@@ -49,9 +49,12 @@ AmConf['OccurenceStore'] = AmConf['ConfHome'] + '/feml_store.pstore';
 
 AmConf['UfromWhiteList'] = AmConf['ConfHome'] + '/ufrom_white_list.txt';
 AmConf['FromWhiteList'] = AmConf['ConfHome'] + '/from_white_list.txt';
+AmConf['SubjectWhiteList'] = AmConf['ConfHome'] + '/subject_white_list.txt';
 AmConf['ReceivedWhiteList'] = AmConf['ConfHome'] + '/received_white_list.txt';
+
 AmConf['UfromBlackList'] = AmConf['ConfHome'] + '/ufrom_black_list.txt';
 AmConf['FromBlackList'] = AmConf['ConfHome'] + '/from_black_list.txt';
+AmConf['SubjectBlackList'] = AmConf['ConfHome'] + '/subject_black_list.txt';
 AmConf['ReceivedBlackList'] = AmConf['ConfHome'] + '/received_black_list.txt';
 
 # =====================================================================
@@ -117,7 +120,7 @@ AmConf['SpamThreshold'] = 0.95;
 # ---------------------------------------------------------------------
 # ---------------------------------------------------------------------
 #
-FemlVersion = 'feml-0.4.0';
+FemlVersion = 'feml-0.5.0';
 
 # =====================================================================
 # ֡뷿ܤˤĤơˤʤäƤ뤫ɤĴ٤롣
@@ -723,6 +726,20 @@ class ExDecoder
 						# ʾNKFѴ
 		end
 
+		# -----------------------------------------------------
+		# Content-Transfer-Encoding: 7bitפǤäƤ⡢
+		#  &nbsp; (0xA0) ɽƵ㤬Τǡ
+		# Ѵ롣
+		#	Content-Transfer-Encoding: 7bitפȤҼΤ
+		#	ǤʤΤǡˤϰ¸ʸ󤽤ΤΤ
+		#	Ĵ٤ȽǤ롣
+		#
+		mtmp = mbuf.clone;
+		mtmp.force_encoding('ASCII-8BIT');
+		if /\A[\x00-\x7F\xA0]+\z/n =~ mtmp
+			mbuf = mtmp.gsub(/\xA0/n, ' ');
+		end
+
 		# -----------------------------------------------------
 		# charsetƤʤޤᡢNKFǥɤ
 		# ¬Ѵ롣
@@ -1388,7 +1405,6 @@ def is_in_list_pattern(target_text, list_class)
 	return false if ! File.file?(list_file);
 
 	File::foreach(list_file) do |buf|
-		buf.force_encoding('ASCII-8BIT');
 		buf = buf.chomp();
 		next if /^#/ =~ buf;
 		next if /^\*/ =~ buf;
@@ -1528,6 +1544,9 @@ def spam_filter(fp_in, user)
 	elsif is_in_list_pattern(received, 'ReceivedWhiteList')
 		result = "FemlWhite (received) (#{spam_prob_percent})";
 		result_mode = :is_white;
+	elsif is_in_list_pattern(subject, 'SubjectWhiteList')
+		result = "FemlWhite (subject) (#{spam_prob_percent})";
+		result_mode = :is_white;
 
 	elsif is_in_list_pattern(unix_from, 'UfromBlackList')
 		result = "FemlBlack (unix_from) [#{spam_prob_percent}]";
@@ -1535,6 +1554,9 @@ def spam_filter(fp_in, user)
 	elsif is_in_list_pattern(mail_from, 'FromBlackList')
 		result = "FemlBlack (mail_from) [#{spam_prob_percent}]";
 		result_mode = :is_black;
+	elsif is_in_list_pattern(subject, 'SubjectBlackList')
+		result = "FemlBlack (subject) [#{spam_prob_percent}]";
+		result_mode = :is_black;
 	elsif is_in_list_pattern(received, 'ReceivedBlackList')
 		result = "FemlBlack (received) [#{spam_prob_percent}]";
 		result_mode = :is_black;
